@@ -1,7 +1,7 @@
 package Data::CSel;
 
 our $DATE = '2016-03-23'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -344,7 +344,25 @@ sub _simpsel {
     #say "D:   intermediate result (after walk): [".join(",",map {$_->{id}} @res)."]";
 
     unless ($simpsel->{type} eq '*') {
-        @res = grep { ref($_) eq $simpsel->{type} } @res;
+        my @fres;
+
+        my @types_to_match;
+        for (@{ $opts->{class_prefixes} // [] }) {
+            push @types_to_match, $_ . (/::$/ ? "" : "::") . $simpsel->{type};
+        }
+        push @types_to_match, $simpsel->{type};
+
+      ELEM:
+        for my $o (@res) {
+            my $ref = ref($o);
+            for (@types_to_match) {
+                if ($ref eq $_) {
+                    push @fres, $o;
+                    next ELEM;
+                }
+            }
+        }
+        @res = @fres;
     }
 
     @res = _uniq_objects(@res);
@@ -562,6 +580,7 @@ sub csel {
     my @nodes = @_;
 
     my $pexpr = parse_csel($expr);
+    $pexpr or die "Invalid CSel expression '$expr'";
 
     my @res = _uniq_objects(map { _sel($opts, $_, @nodes) } @$pexpr );
 
@@ -588,7 +607,7 @@ Data::CSel - Select tree node objects using CSS Selector-like syntax
 
 =head1 VERSION
 
-This document describes version 0.03 of Data::CSel (from Perl distribution Data-CSel), released on 2016-03-23.
+This document describes version 0.04 of Data::CSel (from Perl distribution Data-CSel), released on 2016-03-23.
 
 =head1 SYNOPSIS
 
@@ -626,12 +645,12 @@ F element descendant of an E element. C<< E > F >> means F element child of E
 element. C<E ~ F> means F element preceded by an E element. C<E + F> means F
 element immediately preceded by an E element.
 
-A I<simple selector> is either a L<type selector|/"Type selector"> or
-L<universal selector|/"Universal selector"> followed immediately by zero or more
-L<attribute selectors|/"Attribute selector"> or L<Class selector|"/Class
-selector"> or L<ID selector|/"ID selector"> or
-L<pseudo-classes|"/Pseudo-class">, in any order. Type or universal selector is
-optional if there is at least one attribute selector or pseudo-class.
+A I<simple selector> is either a type selector (see L</"Type selector">) or
+universal selector (see L</"Universal selector">) followed immediately by zero
+or more attribute selectors (see L</"Attribute selector"> or class selector (see
+L<"/Class selector">) or ID selector (see L</"ID selector">) or pseudo-classes
+(see L<"/Pseudo-class">), in any order. Type or universal selector is optional
+if there is at least one attribute selector or pseudo-class.
 
 =head2 Type selector
 
@@ -965,8 +984,8 @@ A I<class selector> is a C<.> (dot) followed by Perl class/package name.
 
  .CLASSNAME
 
-It selects all objects that C<isa()> a certain class. The difference with L<type
-selector|/"Type selector"> is that inheritance is observed. So:
+It selects all objects that C<isa()> a certain class. The difference with type
+selector is that inheritance is observed. So:
 
  .My::Class
 
@@ -983,8 +1002,8 @@ C<id> and the operator is C<=>:
 
  [id = ID]
 
-The L<csel()/"FUNCTIONS"> function allows you to configure which attribute to
-use as the ID attribute, the default is C<id>.
+The C<csel()> function allows you to configure which attribute to use as the ID
+attribute, the default is C<id>.
 
 =head2 Pseudo-class
 
@@ -1149,6 +1168,16 @@ Known options:
 
 =over
 
+=item * class_prefixes => array of str
+
+Array of namespace to check when matching type in type selector as well as class
+selector. This is like PATH environment variable in Unix shell. For example, if
+C<class_prefixes> is C<< ["Foo::Bar", "Baz"] >>, then this expression:
+
+ T
+
+will match class C<Foo::Bar::T>, or C<Baz::T>, or C<T>.
+
 =item * wrap => bool
 
 If set to true, instead of returning a list of matching nodes, the function will
